@@ -41,10 +41,27 @@ def _process(prefix, file_path, obj):
         f.write(file_content)
 
 
+@click.command()
+@click.option("--name", prompt="请输入用户名")
+@click.option("--password", prompt="请输入密码", hide_input=True, confirmation_prompt="请再次输入密码")
+def store(name, password):
+    """
+    存储密码的使用的逻辑，因为要上传到网络上，无法直接把密码写成明文放到代码里，则需要每次存在本地
+    """
+    info_str = "%s\1%s" % (name, password)
+    info = b16encode(info_str.encode("utf-8"))
+    this_path = Path(__file__).parent
+    with this_path.joinpath(".info").open("wb") as f:
+        f.write(info)
+
+
 @click.command()
 @click.option("--overwrite/--no-overwrite", "-o/-no", type=bool, default=True, help="是否直接将原来的文件重写，默认为True")
+@click.option('--username', '-u', type=str, required=False)
+@click.option('--passwd', '-p', type=str, required=False)
 @click.argument("file_paths", type=str, required=True, nargs=-1)
-def process(overwrite, file_paths):
+@click.pass_context
+def process(ctx, overwrite, username, passwd, file_paths):
     """
     处理md文件的主题逻辑，包括查找替换的部分，和上传图片的逻辑。
     """
@@ -52,6 +69,9 @@ def process(overwrite, file_paths):
     if not overwrite:
         prefix = "processed_"
 
+    if username and passwd:
+        ctx.invoke(store, name=username, password=passwd)
+
     with ImgUpload() as obj:
         for each_file in file_paths:  # 遍历每一个路径
             print("处理%s" % each_file)
@@ -66,20 +86,6 @@ def process(overwrite, file_paths):
                     _process(prefix, md_file, obj)
 
 
-@click.command()
-@click.option("--name", prompt="请输入用户名")
-@click.option("--password", prompt="请输入密码", hide_input=True, confirmation_prompt="请再次输入密码")
-def store(name, password):
-    """
-    存储密码的使用的逻辑，因为要上传到网络上，无法直接把密码写成明文放到代码里，则需要每次存在本地
-    """
-    info_str = "%s\1%s" % (name, password)
-    info = b16encode(info_str.encode("utf-8"))
-    this_path = Path(__file__).parent
-    with this_path.joinpath(".info").open("wb") as f:
-        f.write(info)
-
-
 @click.group()
 def cli():
     pass
@@ -91,3 +97,7 @@ cli.add_command(process)
 
 def main():
     cli()
+
+
+if __name__ == "__main__":
+    cli()
